@@ -123,17 +123,9 @@ impl<W> serde::Serializer for Serializer<W> where W: Write {
     }
 }
 
-#[doc(hidden)]
-#[deprecated = "This was published by accident and should not be used. It'll be removed without replacement."]
-pub use internal::NonSeqSerializer;
-
-mod internal {
-use super::*;
-
-#[doc(hidden)]
-pub struct NonSeqSerializer<Writer: Write> {
-    pub(crate) writer: Writer,
-    pub(crate) wrap_long_lines: bool,
+struct NonSeqSerializer<Writer: Write> {
+    writer: Writer,
+    wrap_long_lines: bool,
 }
 
 impl<W> serde::Serializer for NonSeqSerializer<W> where W: Write {
@@ -196,7 +188,6 @@ impl<W> serde::Serializer for NonSeqSerializer<W> where W: Write {
         fn serialize_struct_variant(self, name: &'static str, variant_index: u32, variant: &'static str, len: usize) -> Result<Self::SerializeStructVariant>;
     }
 }
-}
 
 /// Serializer used for serializing sequences of records.
 ///
@@ -216,7 +207,7 @@ impl<W> ser::SerializeSeq for SeqSerializer<W> where W: Write {
         if !self.is_empty {
             writeln!(self.output).map_err(Error::failed_write)?;
         }
-        value.serialize(internal::NonSeqSerializer { writer: &mut self.output, wrap_long_lines: self.wrap_long_lines })
+        value.serialize(NonSeqSerializer { writer: &mut self.output, wrap_long_lines: self.wrap_long_lines })
     }
 
     fn end(self) -> Result<Self::Ok, Self::Error> {
@@ -489,6 +480,10 @@ impl<W> serde::Serializer for FieldSerializer<W> where W: Write {
         value.serialize(self)
     }
 
+    fn serialize_unit_variant(self, _name: &'static str, _variant_index: u32, variant: &'static str) -> Result<(), Self::Error> {
+        self.serialize_str(variant)
+    }
+
     unsupported_types! {
         fn serialize_bool(self, v: bool) -> Result<()>;
         fn serialize_i8(self, v: i8) -> Result<()>;
@@ -505,7 +500,6 @@ impl<W> serde::Serializer for FieldSerializer<W> where W: Write {
         fn serialize_bytes(self, v: &[u8]) -> Result<()>;
         fn serialize_unit(self) -> Result<()>; 
         fn serialize_unit_struct(self, name: &'static str) -> Result<()>; 
-        fn serialize_unit_variant(self, name: &'static str, variant_index: u32, variant: &'static str) -> Result<()>;
         fn serialize_newtype_variant<T>(self, name: &'static str, variant_index: u32, variant: &'static str, value: &T) -> Result<()>
         where
             T: ?Sized + Serialize;
@@ -588,6 +582,10 @@ impl<W> serde::Serializer for StringSerializer<W> where W: Write {
         value.serialize(self)
     }
 
+    fn serialize_unit_variant(self, _name: &'static str, _variant_index: u32, variant: &'static str) -> Result<(), Self::Error> {
+        self.serialize_str(variant)
+    }
+
     unsupported_types! {
         fn serialize_bool(self, v: bool) -> Result<()>;
         fn serialize_i8(self, v: i8) -> Result<()>;
@@ -608,7 +606,6 @@ impl<W> serde::Serializer for StringSerializer<W> where W: Write {
             T: ?Sized + Serialize;
         fn serialize_unit(self) -> Result<()>; 
         fn serialize_unit_struct(self, name: &'static str) -> Result<()>; 
-        fn serialize_unit_variant(self, name: &'static str, variant_index: u32, variant: &'static str) -> Result<()>;
         fn serialize_newtype_variant<T>(self, name: &'static str, variant_index: u32, variant: &'static str, value: &T) -> Result<()>
         where
             T: ?Sized + Serialize;
@@ -938,4 +935,24 @@ mod tests {
         writer.finish().unwrap();
         assert_eq!(output, "satoshi nakamoto\n .\n invented bitcoin\n");
     }
+
+    #[test]
+    fn serialize_unit_variant() {
+        #[derive(serde_derive::Serialize)]
+        #[serde(rename_all = "snake_case")]
+        enum Foo {
+            Bar,
+        }
+
+        #[derive(serde_derive::Serialize)]
+        #[serde(rename_all = "PascalCase")]
+        struct Baz {
+            foo: Foo,
+        }
+
+        let mut out = String::new();
+        let baz = Baz { foo: Foo::Bar, };
+        baz.serialize(Serializer::new(&mut out)).expect("Failed to serialize");
+        assert_eq!(out, "Foo: bar\n");
+    }
 }
